@@ -151,13 +151,14 @@ def authenticate_cvlac(nacionalidad, nombres, documento_identificacion, password
         go_to(login_url)
         
         # Fill in credentials according to actual CVLaC form fields
-        # Select nationality from dropdown using the exact field ID
-        select(nacionalidad, from_=S("#tpo_nacionalidad") or S("[name='tpo_nacionalidad']") or S("select"))
+        # Select nationality from dropdown using fallback logic
+        select("select", nacionalidad)
         
         # If "Extranjero - otra" is selected, wait for and fill "País de nacimiento" field
         if nacionalidad in ["Extranjero - otra", "E"]:
             # Wait for the country field to become visible and fill it
-            select(pais_nacimiento, from_=S("#sgl_pais_nacim") or S("[name='sgl_pais_nacim']"))
+            wait_until(Text("País de nacimiento").exists)
+            select("País de nacimiento",pais_nacimiento)
         
         # Fill in name using the exact field ID
         write(nombres, into=S("#txt_nmes_rh") or S("[name='txt_nmes_rh']") or TextField("Nombres"))
